@@ -1,10 +1,14 @@
 from __future__ import annotations
 
+from typing import get_args
+
 import numpy as np
 import pandas as pd
 import plotly.express as px
 import plotly.graph_objects as go
 
+from mteb.abstasks.TaskMetadata import TASK_TYPE
+
 
 def text_plot(text: str):
     """Returns empty scatter plot with text added, this can be great for error messages."""
@@ -46,21 +50,36 @@ def parse_model_name(name: str) -> str:
 
 def parse_float(value) -> float:
     try:
-        return float(value)
+        if value == "Infinite":
+            return np.inf
+        else:
+            return float(value)
     except ValueError:
         return np.nan
 
 
+def process_max_tokens(x):
+    if pd.isna(x):
+        return "Unknown"
+    if np.isinf(x):
+        return "Infinite"
+    return str(int(x))
+
+
 models_to_annotate = [
     "all-MiniLM-L6-v2",
     "GritLM-7B",
     "LaBSE",
     "multilingual-e5-large-instruct",
+    "EVA02-CLIP-bigE-14-plus",
+    "voyage-multimodal-3",
+    "e5-v",
+    "VLM2Vec-Full",
 ]
 
 
 def add_size_guide(fig: go.Figure):
-    xpos = [5 * 1e9] * 4
+    xpos = [2 * 1e6] * 4
     ypos = [7.8, 8.5, 9, 10]
     sizes = [256, 1024, 2048, 4096]
     fig.add_trace(
@@ -78,25 +97,13 @@ def add_size_guide(fig: go.Figure):
         )
     )
     fig.add_annotation(
-        text="<b>Embedding Size:</b>",
+        text="<b>Embedding Size</b>",
         font=dict(size=16),
-        x=np.log10(1.5e9),
+        x=np.log10(10 * 1e6),
         y=10,
         showarrow=False,
         opacity=0.3,
     )
-    for x, y, size in zip(xpos, np.linspace(7.5, 14, 4), sizes):
-        fig.add_annotation(
-            text=f"<b>{size}</b>",
-            font=dict(size=12),
-            x=np.log10(x),
-            y=y,
-            showarrow=True,
-            ay=0,
-            ax=50,
-            opacity=0.3,
-            arrowwidth=2,
-        )
     return fig
 
 
@@ -117,6 +124,7 @@ def performance_size_plot(df: pd.DataFrame) -> go.Figure:
         return go.Figure()
     min_score, max_score = df["Mean (Task)"].min(), df["Mean (Task)"].max()
     df["sqrt(dim)"] = np.sqrt(df["Embedding Dimensions"])
+    df["Max Tokens"] = df["Max Tokens"].apply(lambda x: process_max_tokens(x))
     fig = px.scatter(
         df,
         x="Number of Parameters",
@@ -127,7 +135,6 @@ def performance_size_plot(df: pd.DataFrame) -> go.Figure:
         size="sqrt(dim)",
         color="Log(Tokens)",
         range_color=[2, 5],
-        range_x=[8 * 1e6, 11 * 1e9],
         range_y=[min(0, min_score * 1.25), max_score * 1.25],
         hover_data={
             "Max Tokens": True,
@@ -140,6 +147,7 @@ def performance_size_plot(df: pd.DataFrame) -> go.Figure:
             "model_text": False,
         },
         hover_name="Model",
+        color_continuous_scale=px.colors.sequential.Greens,
     )
     # Note: it's important that this comes before setting the size mode
     fig = add_size_guide(fig)
@@ -178,21 +186,10 @@ def performance_size_plot(df: pd.DataFrame) -> go.Figure:
 
 
 TOP_N = 5
-task_types = [
-    "BitextMining",
-    "Classification",
-    "MultilabelClassification",
-    "Clustering",
-    "PairClassification",
-    "Reranking",
-    "Retrieval",
-    "STS",
-    "Summarization",
-    # "InstructionRetrieval",
-    # Not displayed, because the scores are negative,
-    # doesn't work well with the radar chart.
-    "Speed",
-]
+task_types = sorted(get_args(TASK_TYPE))
+task_types.remove("InstructionRetrieval")
+# Not displayed, because the scores are negative,
+# doesn't work well with the radar chart.
 
 line_colors = [
     "#EE4266",
@@ -223,7 +220,7 @@ def radar_chart(df: pd.DataFrame) -> go.Figure:
             "Couldn't produce radar chart, the benchmark only contains one task category."
         )
     df = df[["Model", *task_type_columns]].set_index("Model")
-    df = df.replace("", np.nan)
+    df = df.mask(df == "", np.nan)
     df = df.dropna()
     df = df.head(TOP_N)
     df = df.iloc[::-1]
@@ -243,7 +240,7 @@ def radar_chart(df: pd.DataFrame) -> go.Figure:
             )
         )
     fig.update_layout(
-        font=dict(size=16, color="black"),  # noqa
+        font=dict(size=13, color="black"),  # noqa
         template="plotly_white",
         polar=dict(
             radialaxis=dict(
@@ -261,11 +258,15 @@ def radar_chart(df: pd.DataFrame) -> go.Figure:
         legend=dict(
             orientation="h",
             yanchor="bottom",
-            y=-0.6,
-            xanchor="left",
-            x=-0.05,
+            y=-0.35,
+            xanchor="center",
+            x=0.4,
+            itemwidth=30,
+            font=dict(size=13),
+            entrywidth=0.6,
             entrywidthmode="fraction",
-            entrywidth=1 / 5,
         ),
+        margin=dict(l=0, r=16, t=30, b=30),
+        autosize=True,
     )
     return fig
