@@ -21,9 +21,11 @@ from mteb.models import (
     blip2_models,
     blip_models,
     bm25,
+    bmretriever_models,
     cadet_models,
     cde_models,
     clip_models,
+    codefuse_models,
     codesage_models,
     codi_models,
     cohere_models,
@@ -121,8 +123,10 @@ model_modules = [
     blip2_models,
     blip_models,
     bm25,
+    bmretriever_models,
     cadet_models,
     clip_models,
+    codefuse_models,
     codesage_models,
     cde_models,
     cohere_models,
