@@ -47,9 +47,7 @@ class RepLLaMAWrapper(Wrapper):
         # set the max_length for the evals as they did, although the model can handle longer
         self.model.config.max_length = 512
         self.tokenizer.model_max_length = 512
-        self.model_prompts = (
-            self.validate_task_to_prompt_name(model_prompts) if model_prompts else None
-        )
+        self.model_prompts = self.validate_task_to_prompt_name(model_prompts)
 
     def create_batch_dict(self, tokenizer, input_texts):
         max_length = self.model.config.max_length
